"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations

from typing import Literal

import pydantic
from typing_extensions import Annotated, TypedDict

from friendli.types import BaseModel

B64ImageItemFormat = Literal["url", "raw", "png", "jpeg", "jpg"]
r"""The format of the generated image. One of `url(default)`, `raw`, `png`, `jpeg`, and `jpg`."""


class B64ImageItemTypedDict(TypedDict):
    b64_json: bytes
    r"""The base64-encoded JSON of the generated image."""
    format_: B64ImageItemFormat
    r"""The format of the generated image. One of `url(default)`, `raw`, `png`, `jpeg`, and `jpg`."""
    seed: int
    r"""The seed used during image generation."""


class B64ImageItem(BaseModel):
    b64_json: bytes
    r"""The base64-encoded JSON of the generated image."""

    format_: Annotated[B64ImageItemFormat, pydantic.Field(alias="format")]
    r"""The format of the generated image. One of `url(default)`, `raw`, `png`, `jpeg`, and `jpg`."""

    seed: int
    r"""The seed used during image generation."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations

from typing import Literal

import pydantic
from pydantic import model_serializer
from pydantic.functional_validators import AfterValidator
from typing_extensions import Annotated, NotRequired, TypedDict

from friendli.types import UNSET, UNSET_SENTINEL, BaseModel, Nullable, OptionalNullable
from friendli.utils import validate_const


class ToolMessageTypedDict(TypedDict):
    content: str
    r"""The content of tool message that contains the result of tool calling."""
    tool_call_id: str
    r"""The ID of tool call corresponding to this message."""
    role: Literal["tool"]
    r"""The role of the messages author."""
    name: NotRequired[Nullable[str]]
    r"""An optional name of the tool call corresponding to this message."""


class ToolMessage(BaseModel):
    content: str
    r"""The content of tool message that contains the result of tool calling."""

    tool_call_id: str
    r"""The ID of tool call corresponding to this message."""

    ROLE: Annotated[
        Annotated[Literal["tool"], AfterValidator(validate_const("tool"))],
        pydantic.Field(alias="role"),
    ] = "tool"
    r"""The role of the messages author."""

    name: OptionalNullable[str] = UNSET
    r"""An optional name of the tool call corresponding to this message."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["name"]
        nullable_fields = ["name"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations

from typing import List

import pydantic
from pydantic import model_serializer
from typing_extensions import Annotated, NotRequired, TypedDict

from friendli.types import UNSET, UNSET_SENTINEL, BaseModel, Nullable, OptionalNullable

from .chatlogprobscontenttoplogprob import (
    ChatLogprobsContentTopLogprob,
    ChatLogprobsContentTopLogprobTypedDict,
)


class ChatLogprobsContentTypedDict(TypedDict):
    logprob: float
    r"""The log probability of this token."""
    token: str
    r"""The token."""
    top_logprobs: List[ChatLogprobsContentTopLogprobTypedDict]
    r"""List of the most likely tokens and their log probability, at this token position."""
    bytes_: NotRequired[Nullable[List[int]]]
    r"""A list of integers representing the UTF-8 bytes representation of the token. Useful in instances where characters are represented by multiple tokens and their byte representations must be combined to generate the correct text representation. Can be `null` if there is no bytes representation for the token."""


class ChatLogprobsContent(BaseModel):
    logprob: float
    r"""The log probability of this token."""

    token: str
    r"""The token."""

    top_logprobs: List[ChatLogprobsContentTopLogprob]
    r"""List of the most likely tokens and their log probability, at this token position."""

    bytes_: Annotated[OptionalNullable[List[int]], pydantic.Field(alias="bytes")] = (
        UNSET
    )
    r"""A list of integers representing the UTF-8 bytes representation of the token. Useful in instances where characters are represented by multiple tokens and their byte representations must be combined to generate the correct text representation. Can be `null` if there is no bytes representation for the token."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["bytes"]
        nullable_fields = ["bytes"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m
